@@ -1,5 +1,9 @@
-mice.impute.pmm6 <- function (y, ry, x, donors=3 , noise = 10^5 , ridge = 10^(-5) , ...){
-    x <- cbind(1, as.matrix(x))
+## File Name: mice.impute.pmm6.R
+## File Version: 0.11
+
+mice.impute.pmm6 <- function (y, ry, x, donors=3 , noise = 10^5 , ridge = 10^(-5) , ...)
+{
+	x <- cbind(1, as.matrix(x))
 	# dummy response indicator 
 	ry01 <- 1*ry
 	# sample regression coefficients
@@ -10,6 +14,8 @@ mice.impute.pmm6 <- function (y, ry, x, donors=3 , noise = 10^5 , ridge = 10^(-5
 	# Rcpp code
 	# SEXP ma_pmm6_C( SEXP y_, SEXP ry01_, SEXP x_, SEXP ridge_, 
 	#          SEXP coefu_, SEXP donorsample_) ;	
-	imp <- ma_pmm6_C(y ,  ry01 , x, ridge , coefu , donorsample	)
-    return(imp)
+	imp <- .Call("ma_pmm6_C", 
+				y_=y ,  ry01_=ry01 ,  x_=x,  ridge_=ridge ,  coefu_=coefu ,  donorsample_=donorsample	,
+				PACKAGE = "miceadds")	
+	return(imp)
 }
