@@ -1,3 +1,5 @@
+## File Name: mice_imputation_weighted_norm_draw.R
+## File Version: 0.03
 	
 #***** .weighted.norm.draw *******************
 mice_imputation_weighted_norm_draw <- function( yobs , xobs , ry , y , x , 
@@ -6,7 +8,9 @@ mice_imputation_weighted_norm_draw <- function( yobs , xobs , ry , y , x ,
     # X'*W*X
     xtx <- t(xobs) %*% WW %*% xobs
     pen <- ridge * diag(xtx)
-    if (length(pen)==1) pen <- matrix(pen)
+    if (length(pen)==1){
+		pen <- matrix(pen)
+	}
     v <- solve(xtx + diag(pen))
     # V * ( X'*W*Y)
     coef <- t(yobs %*% WW %*% xobs %*% v)
